<head>
  <meta charset="utf-8" />
  {% if css %}
  <style type="text/css">
    {{ css }}
  </style>
  {% endif %}
</head>
<body>
  <div id="main" class="main-box">
    <div class="text">{{ text }}</div>
  </div>
</body>
